@@ -1,22 +1,24 @@
-from typing import Type, TypeVar
+from typing import Any, Type, TypeVar
 from aiohttp import ClientSession
 from urllib.parse import urljoin
 
 from python_swos_lite.endpoint import SwOSLiteEndpoint, readDataclass
+from python_swos_lite.http import HttpClient, createHttpClient
 
 T = TypeVar("T", bound=SwOSLiteEndpoint)
 
 class Client:
     """Client to connect to the available endpoints"""
     host: str
-    session: ClientSession
+    httpClient: HttpClient
 
-    def __init__(self, session: ClientSession, host: str):
-        self.session = session
+    def __init__(self, httpClient: HttpClient, host: str):
+        self.httpClient = httpClient
         self.host = host.rstrip("/") + "/"  # Make sure host ends with a single "/"
 
     async def fetch(self, cls: Type[T]) -> T:
-        async with self.session.get(urljoin(self.host, cls.endpoint_path)) as response:
+        response = await self.httpClient.get(urljoin(self.host, cls.endpoint_path))
+        async with response:
             response.raise_for_status()
             text = await response.text()
             return readDataclass(cls, text)
